import { PrimitivesObject, ScalarObject } from 'datapipe-js';
export interface SqlSaveStatus {
    inserted: number;
    updated: number;
    deleted: number;
}
export interface SqlReadQueryInfo {
    filter?: string;
    filterParams?: PrimitivesObject;
    skip?: number;
    top?: number;
    orderBy?: string;
    mainTableAlias?: string;
    joins: string;
}
export interface SqlSaveOptions {
    chunkSize?: number;
    primaryKeys: string[];
    method: 'Merge' | 'Append' | 'BulkInsert';
}
export declare function setBaseUrl(baseUrl: string): void;
export declare function setUserAccessToken(userAccessToken: string): void;
export declare function authenticate(username: string, password: string): Promise<boolean>;
export declare function sqlDataApi(connectionName: string, config?: {
    baseUrl?: string;
    userAccessToken?: string;
    bearerToken?: string;
}): SqlDataApi;
export declare class SqlDataApi {
    private baseUrl;
    private connectionName;
    private readonly userAccessToken?;
    private readonly bearerToken?;
    static BaseUrl: string;
    static UserAccessToken: string;
    static BearerToken: string;
    constructor(baseUrl: string, connectionName: string, config: {
        userAccessToken?: string;
        bearerToken?: string;
    });
    query(tableOrViewName: string, fields?: string, queryInfo?: SqlReadQueryInfo): Promise<ScalarObject[]>;
    save(tableName: string, items: ScalarObject[], saveOptions?: SqlSaveOptions): Promise<SqlSaveStatus>;
    sqlExecute(sql: string, params?: ScalarObject): Promise<ScalarObject[] | unknown>;
    private toPrimitive;
}
//# sourceMappingURL=sql-data.api.d.ts.map